#include <R_ext/RS.h>
#include <stdlib.h> // for NULL
#include <R_ext/Rdynload.h>

/* FIXME: 
   Check these declarations against the C/Fortran source code.
*/

/* .Fortran calls */
extern void F77_NAME(nmixsub)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *,
                              void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, 
                              void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, 
                              void *);

static const R_FortranMethodDef FortranEntries[] = {
    {"nmixsub", (DL_FUNC) &F77_NAME(nmixsub), 31},
    {NULL, NULL, 0}
};

void R_init_Nmix(DllInfo *dll)
{
    R_registerRoutines(dll, NULL, NULL, FortranEntries, NULL);
    R_useDynamicSymbols(dll, FALSE);
}
